@@ -34,6 +34,7 @@
 #include <QTest>
 #include <QUrl>
 
+#include <kmountpoint.h>
 #include <kprotocolinfo.h>
 #include <kio/scheduler.h>
 #include <kio/directorysizejob.h>
@@ -59,6 +60,15 @@ static QString otherTmpDir()
 #endif
 }
 
+static bool otherTmpDirIsOnSamePartition() // true on CI because it's a LXC container
+{
+    KMountPoint::Ptr srcMountPoint = KMountPoint::currentMountPoints().findByPath(homeTmpDir());
+    KMountPoint::Ptr destMountPoint = KMountPoint::currentMountPoints().findByPath(otherTmpDir());
+    Q_ASSERT(srcMountPoint);
+    Q_ASSERT(destMountPoint);
+    return srcMountPoint->mountedFrom() == destMountPoint->mountedFrom();
+}
+
 #if 0
 static QUrl systemTmpDir()
 {
@@ -124,8 +134,8 @@ void JobTest::cleanupTestCase()
 void JobTest::enterLoop()
 {
     QEventLoop eventLoop;
-    connect(this, SIGNAL(exitLoop()),
-            &eventLoop, SLOT(quit()));
+    connect(this, &JobTest::exitLoop,
+            &eventLoop, &QEventLoop::quit);
     eventLoop.exec(QEventLoop::ExcludeUserInputEvents);
 }
 
@@ -141,8 +151,8 @@ void JobTest::storedGet()
     QSignalSpy spyPercent(job, SIGNAL(percent(KJob*,ulong)));
     QVERIFY(spyPercent.isValid());
     job->setUiDelegate(nullptr);
-    connect(job, SIGNAL(result(KJob*)),
-            this, SLOT(slotGetResult(KJob*)));
+    connect(job, &KJob::result,
+            this, &JobTest::slotGetResult);
     enterLoop();
     QCOMPARE(m_result, 0);   // no error
     QCOMPARE(m_data, QByteArray("Hello\0world", 11));
@@ -162,14 +172,14 @@ void JobTest::put()
     const QString filePath = homeTmpDir() + "fileFromHome";
     QUrl u = QUrl::fromLocalFile(filePath);
     KIO::TransferJob *job = KIO::put(u, 0600, KIO::Overwrite | KIO::HideProgressInfo);
-    QDateTime mtime = QDateTime::currentDateTime().addSecs(-30);   // 30 seconds ago
-    mtime.setTime_t(mtime.toTime_t()); // hack for losing the milliseconds
+    quint64 secsSinceEpoch = QDateTime::currentSecsSinceEpoch(); // Use second granularity, supported on all filesystems
+    QDateTime mtime = QDateTime::fromSecsSinceEpoch(secsSinceEpoch - 30); // 30 seconds ago
     job->setModificationTime(mtime);
     job->setUiDelegate(nullptr);
-    connect(job, SIGNAL(result(KJob*)),
-            this, SLOT(slotResult(KJob*)));
-    connect(job, SIGNAL(dataReq(KIO::Job*,QByteArray&)),
-            this, SLOT(slotDataReq(KIO::Job*,QByteArray&)));
+    connect(job, &KJob::result,
+            this, &JobTest::slotResult);
+    connect(job, &KIO::TransferJob::dataReq,
+            this, &JobTest::slotDataReq);
     m_result = -1;
     m_dataReqCount = 0;
     enterLoop();
@@ -212,8 +222,8 @@ void JobTest::storedPut()
     KIO::TransferJob *job = KIO::storedPut(putData, u, 0600, KIO::Overwrite | KIO::HideProgressInfo);
     QSignalSpy spyPercent(job, SIGNAL(percent(KJob*,ulong)));
     QVERIFY(spyPercent.isValid());
-    QDateTime mtime = QDateTime::currentDateTime().addSecs(-30);   // 30 seconds ago
-    mtime.setTime_t(mtime.toTime_t()); // hack for losing the milliseconds
+    quint64 secsSinceEpoch = QDateTime::currentSecsSinceEpoch(); // Use second granularity, supported on all filesystems
+    QDateTime mtime = QDateTime::fromSecsSinceEpoch(secsSinceEpoch - 30); // 30 seconds ago
     job->setModificationTime(mtime);
     job->setUiDelegate(nullptr);
     QVERIFY(job->exec());
@@ -234,8 +244,8 @@ void JobTest::storedPutIODevice()
     KIO::TransferJob *job = KIO::storedPut(&putData, QUrl::fromLocalFile(filePath), 0600, KIO::Overwrite | KIO::HideProgressInfo);
     QSignalSpy spyPercent(job, SIGNAL(percent(KJob*,ulong)));
     QVERIFY(spyPercent.isValid());
-    QDateTime mtime = QDateTime::currentDateTime().addSecs(-30);   // 30 seconds ago
-    mtime.setTime_t(mtime.toTime_t()); // hack for losing the milliseconds
+    quint64 secsSinceEpoch = QDateTime::currentSecsSinceEpoch(); // Use second granularity, supported on all filesystems
+    QDateTime mtime = QDateTime::fromSecsSinceEpoch(secsSinceEpoch - 30); // 30 seconds ago
     job->setModificationTime(mtime);
     job->setUiDelegate(nullptr);
     QVERIFY(job->exec());
@@ -307,8 +317,8 @@ void JobTest::storedPutIODeviceFastDevice()
     KIO::StoredTransferJob *job = KIO::storedPut(&putDataBuffer, u, 0600, KIO::Overwrite | KIO::HideProgressInfo);
     QSignalSpy spyPercent(job, SIGNAL(percent(KJob*,ulong)));
     QVERIFY(spyPercent.isValid());
-    QDateTime mtime = QDateTime::currentDateTime().addSecs(-30);   // 30 seconds ago
-    mtime.setTime_t(mtime.toTime_t()); // hack for losing the milliseconds
+    quint64 secsSinceEpoch = QDateTime::currentSecsSinceEpoch(); // Use second granularity, supported on all filesystems
+    QDateTime mtime = QDateTime::fromSecsSinceEpoch(secsSinceEpoch - 30); // 30 seconds ago
     job->setModificationTime(mtime);
     job->setTotalSize(putDataContents.size());
     job->setUiDelegate(nullptr);
@@ -343,8 +353,8 @@ void JobTest::storedPutIODeviceSlowDevice()
     KIO::StoredTransferJob *job = KIO::storedPut(&putDataBuffer, u, 0600, KIO::Overwrite | KIO::HideProgressInfo);
     QSignalSpy spyPercent(job, SIGNAL(percent(KJob*,ulong)));
     QVERIFY(spyPercent.isValid());
-    QDateTime mtime = QDateTime::currentDateTime().addSecs(-30);   // 30 seconds ago
-    mtime.setTime_t(mtime.toTime_t()); // hack for losing the milliseconds
+    quint64 secsSinceEpoch = QDateTime::currentSecsSinceEpoch(); // Use second granularity, supported on all filesystems
+    QDateTime mtime = QDateTime::fromSecsSinceEpoch(secsSinceEpoch - 30); // 30 seconds ago
     job->setModificationTime(mtime);
     job->setTotalSize(putDataContents.size());
     job->setUiDelegate(nullptr);
@@ -386,8 +396,8 @@ void JobTest::storedPutIODeviceSlowDeviceBigChunk()
     KIO::StoredTransferJob *job = KIO::storedPut(&putDataBuffer, u, 0600, KIO::Overwrite | KIO::HideProgressInfo);
     QSignalSpy spyPercent(job, SIGNAL(percent(KJob*,ulong)));
     QVERIFY(spyPercent.isValid());
-    QDateTime mtime = QDateTime::currentDateTime().addSecs(-30);   // 30 seconds ago
-    mtime.setTime_t(mtime.toTime_t()); // hack for losing the milliseconds
+    quint64 secsSinceEpoch = QDateTime::currentSecsSinceEpoch(); // Use second granularity, supported on all filesystems
+    QDateTime mtime = QDateTime::fromSecsSinceEpoch(secsSinceEpoch - 30); // 30 seconds ago
     job->setModificationTime(mtime);
     job->setTotalSize(putDataContents.size());
     job->setUiDelegate(nullptr);
@@ -996,8 +1006,8 @@ void JobTest::listRecursive()
 #endif
     KIO::ListJob *job = KIO::listRecursive(QUrl::fromLocalFile(src), KIO::HideProgressInfo);
     job->setUiDelegate(nullptr);
-    connect(job, SIGNAL(entries(KIO::Job*,KIO::UDSEntryList)),
-            SLOT(slotEntries(KIO::Job*,KIO::UDSEntryList)));
+    connect(job, &KIO::ListJob::entries,
+            this, &JobTest::slotEntries);
     bool ok = job->exec();
     QVERIFY(ok);
     m_names.sort();
@@ -1721,6 +1731,57 @@ void JobTest::moveDestAlreadyExistsAutoRename(const QString &destDir, bool moveD
     }
 }
 
+void JobTest::safeOverwrite_data()
+{
+    QTest::addColumn<bool>("destFileExists");
+
+    QTest::newRow("dest file exists") << true;
+    QTest::newRow("dest file doesn't exist") << false;
+}
+
+void JobTest::safeOverwrite()
+{
+#ifdef Q_OS_WIN
+    QSKIP("Test skipped on Windows");
+#endif
+
+    QFETCH(bool, destFileExists);
+    const QString srcDir = homeTmpDir() + "overwrite";
+    const QString srcFile = srcDir + "/testfile";
+    const QString destDir = otherTmpDir() + "overwrite_other";
+    const QString destFile = destDir + "/testfile";
+    const QString destPartFile = destFile + ".part";
+
+    createTestDirectory(srcDir);
+    createTestDirectory(destDir);
+
+    QVERIFY(QFile::resize(srcFile, 1000000)); //~1MB
+    if (!destFileExists) {
+        QVERIFY(QFile::remove(destFile));
+    }
+
+    if (otherTmpDirIsOnSamePartition()) {
+        QSKIP(qPrintable(QStringLiteral("This test requires %1 and %2 to be on different partitions").arg(srcDir, destDir)));
+    }
+
+    KIO::FileCopyJob *job = KIO::file_move(QUrl::fromLocalFile(srcFile), QUrl::fromLocalFile(destFile), -1, KIO::HideProgressInfo | KIO::Overwrite);
+    job->setUiDelegate(nullptr);
+    QSignalSpy spyTotalSize(job, &KIO::FileCopyJob::totalSize);
+    connect(job, &KIO::FileCopyJob::totalSize, this, [destFileExists, destPartFile](KJob *job, qulonglong totalSize) {
+        Q_UNUSED(job);
+        Q_UNUSED(totalSize);
+        QCOMPARE(destFileExists, QFile::exists(destPartFile));
+    });
+    QVERIFY(job->exec());
+    QVERIFY(QFile::exists(destFile));
+    QVERIFY(!QFile::exists(srcFile));
+    QVERIFY(!QFile::exists(destPartFile));
+    QCOMPARE(spyTotalSize.count(), 1);
+
+    QDir(srcDir).removeRecursively();
+    QDir(destDir).removeRecursively();
+}
+
 void JobTest::moveAndOverwrite()
 {
     const QString sourceFile = homeTmpDir() + "fileFromHome";
@@ -1997,3 +2058,63 @@ void JobTest::multiGet()
     }
 }
 
+void JobTest::cancelCopyAndCleanDest_data()
+{
+    QTest::addColumn<bool>("suspend");
+    QTest::addColumn<bool>("overwrite");
+
+    QTest::newRow("suspend_no_overwrite") << true << false;
+    QTest::newRow("no_suspend_no_overwrite") << false << false;
+
+#ifndef Q_OS_WIN
+    QTest::newRow("suspend_with_overwrite") << true << true;
+    QTest::newRow("no_suspend_with_overwrite") << false << true;
+#endif
+}
+
+void JobTest::cancelCopyAndCleanDest()
+{
+    QFETCH(bool, suspend);
+    QFETCH(bool, overwrite);
+
+    const QString baseDir = homeTmpDir();
+    const QString srcTemplate = baseDir + QStringLiteral("testfile_XXXXXX");
+    const QString destFile = baseDir + QStringLiteral("testfile_copy");
+
+
+    QTemporaryFile f(srcTemplate);
+    if (!f.open()) {
+        qFatal("Couldn't open %s", qPrintable(f.fileName()));
+    }
+    f.seek(9999999);
+    f.write("0");
+    f.close();
+    QCOMPARE(f.size(), 10000000); //~10MB
+
+    if (overwrite) {
+        createTestFile(destFile);
+    }
+
+    KIO::JobFlag m_overwriteFlag = overwrite ? KIO::Overwrite : KIO::DefaultFlags;
+    KIO::FileCopyJob *copyJob = KIO::file_copy(QUrl::fromLocalFile(f.fileName()), QUrl::fromLocalFile(destFile), -1, KIO::HideProgressInfo | m_overwriteFlag);
+    copyJob->setUiDelegate(nullptr);
+    QSignalSpy spyProcessedSize(copyJob, &KIO::Job::processedSize);
+    connect(copyJob, &KIO::Job::processedSize, this, [destFile, suspend, overwrite](KJob *job, qulonglong processedSize) {
+        if (processedSize > 0) {
+            const QString destToCheck = (!overwrite) ? destFile : destFile + QStringLiteral(".part");
+            QVERIFY2(QFile::exists(destToCheck), qPrintable(destToCheck));
+            if (suspend) {
+                job->suspend();
+            }
+            job->kill();
+            QVERIFY(!QFile::exists(destToCheck));
+        }
+    });
+    QVERIFY(!copyJob->exec());
+    QCOMPARE(spyProcessedSize.count(), 1);
+    // Give time to the kioslave to finish copy() and warn about chown/chmod failing (because FileCopyJob::doKill removed the file)
+    // Less confusing if the warnings show here.
+    QTest::qWait(500);
+    QVERIFY(!QFile::exists(destFile));
+}
+
