@@ -20,8 +20,8 @@
 #ifndef JOBTEST_H
 #define JOBTEST_H
 
-#include <QtCore/QString>
-#include <QtCore/QObject>
+#include <QString>
+#include <QObject>
 #include <kio/job.h>
 
 class JobTest : public QObject
@@ -42,8 +42,10 @@ private Q_SLOTS:
     void storedPutIODevice();
     void storedPutIODeviceFile();
     void storedPutIODeviceTempFile();
+    void storedPutIODeviceFastDevice();
     void storedPutIODeviceSlowDevice();
     void storedPutIODeviceSlowDeviceBigChunk();
+    void asyncStoredPutReadyReadAfterFinish();
     void copyFileToSamePartition();
     void copyDirectoryToSamePartition();
     void copyDirectoryToExistingDirectory();
@@ -95,6 +97,8 @@ private Q_SLOTS:
     void moveDestAlreadyExistsAutoRename_data();
     void moveDestAlreadyExistsAutoRename();
 
+    void safeOverwrite();
+    void safeOverwrite_data();
     void moveAndOverwrite();
     void moveOverSymlinkToSelf();
     void createSymlink();
@@ -105,6 +109,9 @@ private Q_SLOTS:
     void createSymlinkWithOverwriteShouldWork();
     void createBrokenSymlink();
 
+    void cancelCopyAndCleanDest();
+    void cancelCopyAndCleanDest_data();
+
     // Remote tests
     //void copyFileToSystem();
 
