@@ -32,6 +32,7 @@ class KFileItemListPropertiesPrivate : public QSharedData
 public:
     KFileItemListPropertiesPrivate()
         : m_isDirectory(false),
+          m_isFile(false),
           m_supportsReading(false),
           m_supportsDeleting(false),
           m_supportsWriting(false),
@@ -46,6 +47,7 @@ public:
     mutable QString m_mimeType;
     mutable QString m_mimeGroup;
     bool m_isDirectory : 1;
+    bool m_isFile : 1;
     bool m_supportsReading : 1;
     bool m_supportsDeleting : 1;
     bool m_supportsWriting : 1;
@@ -78,14 +80,16 @@ void KFileItemListPropertiesPrivate::setItems(const KFileItemList &items)
     m_supportsWriting = initialValue;
     m_supportsMoving = initialValue;
     m_isDirectory = initialValue;
+    m_isFile = initialValue;
     m_isLocal = true;
     m_mimeType.clear();
     m_mimeGroup.clear();
 
     QFileInfo parentDirInfo;
     foreach (const KFileItem &item, items) {
-        const QUrl url = item.url();
-        m_isLocal = m_isLocal && url.isLocalFile();
+        bool isLocal = false;
+        const QUrl url = item.mostLocalUrl(&isLocal);
+        m_isLocal = m_isLocal && isLocal;
         m_supportsReading  = m_supportsReading  && KProtocolManager::supportsReading(url);
         m_supportsDeleting = m_supportsDeleting && KProtocolManager::supportsDeleting(url);
         m_supportsWriting  = m_supportsWriting  && KProtocolManager::supportsWriting(url) && item.isWritable();
@@ -113,6 +117,10 @@ void KFileItemListPropertiesPrivate::setItems(const KFileItemList &items)
         if (m_isDirectory && !item.isDir()) {
             m_isDirectory = false;
         }
+
+        if (m_isFile && !item.isFile()) {
+            m_isFile = false;
+        }
     }
 }
 
@@ -170,6 +178,11 @@ bool KFileItemListProperties::isDirectory() const
     return d->m_isDirectory;
 }
 
+bool KFileItemListProperties::isFile() const
+{
+    return d->m_isFile;
+}
+
 QString KFileItemListProperties::mimeType() const
 {
     if (d->m_mimeType.isEmpty()) {
@@ -190,14 +203,14 @@ void KFileItemListPropertiesPrivate::determineMimeTypeAndGroup() const
 {
     if (!m_items.isEmpty()) {
         m_mimeType = m_items.first().mimetype();
-        m_mimeGroup = m_mimeType.left(m_mimeType.indexOf('/'));
+        m_mimeGroup = m_mimeType.left(m_mimeType.indexOf(QLatin1Char('/')));
     }
     foreach (const KFileItem &item, m_items) {
         const QString itemMimeType = item.mimetype();
         // Determine if common mimetype among all items
         if (m_mimeType != itemMimeType) {
             m_mimeType.clear();
-            if (m_mimeGroup != itemMimeType.left(itemMimeType.indexOf('/'))) {
+            if (m_mimeGroup != itemMimeType.leftRef(itemMimeType.indexOf(QLatin1Char('/')))) {
                 m_mimeGroup.clear(); // mimetype groups are different as well!
             }
         }
