@@ -164,6 +164,8 @@ void KDirOperator::keyPressEvent(QKeyEvent *e)
 {
     if (!(e->key() == Qt::Key_Return || e->key() == Qt::Key_Enter)) {
         QWidget::keyPressEvent(e);
+    } else {
+        emit keyEnterReturnPressed();
     }
 }
 
@@ -2105,7 +2107,7 @@ void KDirOperator::updateViewActions()
 void KDirOperator::readConfig(const KConfigGroup &configGroup)
 {
     d->defaultView = 0;
-    QString viewStyle = configGroup.readEntry("View Style", "Simple");
+    QString viewStyle = configGroup.readEntry("View Style", "DetailTree");
     if (viewStyle == QLatin1String("Detail")) {
         d->defaultView |= KFile::Detail;
     } else if (viewStyle == QLatin1String("Tree")) {
