@@ -61,26 +61,26 @@ struct Margin {
     int left, right, top, bottom;
 };
 
-class KFileItemDelegate::Private
+class Q_DECL_HIDDEN KFileItemDelegate::Private
 {
 public:
     enum MarginType { ItemMargin = 0, TextMargin, IconMargin, NMargins };
 
-    Private(KFileItemDelegate *parent);
+    explicit Private(KFileItemDelegate *parent);
     ~Private() {}
 
-    QSize decorationSizeHint(const QStyleOptionViewItemV4 &option, const QModelIndex &index) const;
-    QSize displaySizeHint(const QStyleOptionViewItemV4 &option, const QModelIndex &index) const;
+    QSize decorationSizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const;
+    QSize displaySizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const;
     QString replaceNewlines(const QString &string) const;
     inline KFileItem fileItem(const QModelIndex &index) const;
-    QString elidedText(QTextLayout &layout, const QStyleOptionViewItemV4 &option, const QSize &maxSize) const;
-    QSize layoutText(QTextLayout &layout, const QStyleOptionViewItemV4 &option,
+    QString elidedText(QTextLayout &layout, const QStyleOptionViewItem &option, const QSize &maxSize) const;
+    QSize layoutText(QTextLayout &layout, const QStyleOptionViewItem &option,
                      const QString &text, const QSize &constraints) const;
     QSize layoutText(QTextLayout &layout, const QString &text, int maxWidth) const;
-    inline void setLayoutOptions(QTextLayout &layout, const QStyleOptionViewItemV4 &options) const;
-    inline bool verticalLayout(const QStyleOptionViewItemV4 &option) const;
-    inline QBrush brush(const QVariant &value, const QStyleOptionViewItemV4 &option) const;
-    QBrush foregroundBrush(const QStyleOptionViewItemV4 &option, const QModelIndex &index) const;
+    inline void setLayoutOptions(QTextLayout &layout, const QStyleOptionViewItem &options) const;
+    inline bool verticalLayout(const QStyleOptionViewItem &option) const;
+    inline QBrush brush(const QVariant &value, const QStyleOptionViewItem &option) const;
+    QBrush foregroundBrush(const QStyleOptionViewItem &option, const QModelIndex &index) const;
     inline void setActiveMargins(Qt::Orientation layout);
     void setVerticalMargin(MarginType type, int left, int right, int top, int bottom);
     void setHorizontalMargin(MarginType type, int left, int right, int top, int bottom);
@@ -91,27 +91,27 @@ public:
     inline QSize addMargin(const QSize &size, MarginType type) const;
     inline QSize subtractMargin(const QSize &size, MarginType type) const;
     QString itemSize(const QModelIndex &index, const KFileItem &item) const;
-    QString information(const QStyleOptionViewItemV4 &option, const QModelIndex &index, const KFileItem &item) const;
-    bool isListView(const QStyleOptionViewItemV4 &option) const;
+    QString information(const QStyleOptionViewItem &option, const QModelIndex &index, const KFileItem &item) const;
+    bool isListView(const QStyleOptionViewItem &option) const;
     QString display(const QModelIndex &index) const;
-    QIcon decoration(const QStyleOptionViewItemV4 &option, const QModelIndex &index) const;
-    QPoint iconPosition(const QStyleOptionViewItemV4 &option) const;
-    QRect labelRectangle(const QStyleOptionViewItemV4 &option) const;
-    void layoutTextItems(const QStyleOptionViewItemV4 &option, const QModelIndex &index,
+    QIcon decoration(const QStyleOptionViewItem &option, const QModelIndex &index) const;
+    QPoint iconPosition(const QStyleOptionViewItem &option) const;
+    QRect labelRectangle(const QStyleOptionViewItem &option) const;
+    void layoutTextItems(const QStyleOptionViewItem &option, const QModelIndex &index,
                          QTextLayout *labelLayout, QTextLayout *infoLayout, QRect *textBoundingRect) const;
     void drawTextItems(QPainter *painter, const QTextLayout &labelLayout, const QTextLayout &infoLayout,
                        const QRect &textBoundingRect) const;
-    KIO::AnimationState *animationState(const QStyleOptionViewItemV4 &option, const QModelIndex &index,
+    KIO::AnimationState *animationState(const QStyleOptionViewItem &option, const QModelIndex &index,
                                         const QAbstractItemView *view) const;
     void restartAnimation(KIO::AnimationState *state);
     QPixmap applyHoverEffect(const QPixmap &icon) const;
     QPixmap transition(const QPixmap &from, const QPixmap &to, qreal amount) const;
-    void initStyleOption(QStyleOptionViewItemV4 *option, const QModelIndex &index) const;
-    void drawFocusRect(QPainter *painter, const QStyleOptionViewItemV4 &option, const QRect &rect) const;
+    void initStyleOption(QStyleOptionViewItem *option, const QModelIndex &index) const;
+    void drawFocusRect(QPainter *painter, const QStyleOptionViewItem &option, const QRect &rect) const;
 
     void gotNewIcon(const QModelIndex &index);
 
-    void paintJobTransfers(QPainter *painter, const qreal &jobAnimationAngle, const QPoint &iconPos, const QStyleOptionViewItemV4 &opt);
+    void paintJobTransfers(QPainter *painter, const qreal &jobAnimationAngle, const QPoint &iconPos, const QStyleOptionViewItem &opt);
 
 public:
     KFileItemDelegate::InformationList informationList;
@@ -134,7 +134,7 @@ private:
 KFileItemDelegate::Private::Private(KFileItemDelegate *parent)
     : shadowColor(Qt::transparent), shadowOffset(1, 1), shadowBlur(2), maximumSize(0, 0),
       showToolTipWhenElided(true), wrapMode(QTextOption::WrapAtWordBoundaryOrAnywhere), jobTransfersVisible(false),
-      animationHandler(new KIO::DelegateAnimationHandler(parent)), activeMargins(0)
+      animationHandler(new KIO::DelegateAnimationHandler(parent)), activeMargins(nullptr)
 {
 }
 
@@ -172,28 +172,28 @@ void KFileItemDelegate::Private::setHorizontalMargin(MarginType type, int horizo
 
 QRect KFileItemDelegate::Private::addMargin(const QRect &rect, MarginType type) const
 {
-    Q_ASSERT(activeMargins != 0);
+    Q_ASSERT(activeMargins != nullptr);
     const Margin &m = activeMargins[type];
     return rect.adjusted(-m.left, -m.top, m.right, m.bottom);
 }
 
 QRect KFileItemDelegate::Private::subtractMargin(const QRect &rect, MarginType type) const
 {
-    Q_ASSERT(activeMargins != 0);
+    Q_ASSERT(activeMargins != nullptr);
     const Margin &m = activeMargins[type];
     return rect.adjusted(m.left, m.top, -m.right, -m.bottom);
 }
 
 QSize KFileItemDelegate::Private::addMargin(const QSize &size, MarginType type) const
 {
-    Q_ASSERT(activeMargins != 0);
+    Q_ASSERT(activeMargins != nullptr);
     const Margin &m = activeMargins[type];
     return QSize(size.width() + m.left + m.right, size.height() + m.top + m.bottom);
 }
 
 QSize KFileItemDelegate::Private::subtractMargin(const QSize &size, MarginType type) const
 {
-    Q_ASSERT(activeMargins != 0);
+    Q_ASSERT(activeMargins != nullptr);
     const Margin &m = activeMargins[type];
     return QSize(size.width() - m.left - m.right, size.height() - m.top - m.bottom);
 }
@@ -221,7 +221,7 @@ QString KFileItemDelegate::Private::itemSize(const QModelIndex &index, const KFi
 }
 
 // Returns the additional information string, if one should be shown, or an empty string otherwise
-QString KFileItemDelegate::Private::information(const QStyleOptionViewItemV4 &option, const QModelIndex &index,
+QString KFileItemDelegate::Private::information(const QStyleOptionViewItem &option, const QModelIndex &index,
         const KFileItem &item) const
 {
     QString string;
@@ -249,7 +249,7 @@ QString KFileItemDelegate::Private::information(const QStyleOptionViewItemV4 &op
             break;
 
         case KFileItemDelegate::OctalPermissions:
-            string += QString('0') + QString::number(item.permissions(), 8);
+            string += QLatin1Char('0') + QString::number(item.permissions(), 8);
             break;
 
         case KFileItemDelegate::Owner:
@@ -257,7 +257,7 @@ QString KFileItemDelegate::Private::information(const QStyleOptionViewItemV4 &op
             break;
 
         case KFileItemDelegate::OwnerAndGroup:
-            string += item.user() + ':' + item.group();
+            string += item.user() + QLatin1Char(':') + item.group();
             break;
 
         case KFileItemDelegate::CreationTime:
@@ -326,7 +326,7 @@ QString KFileItemDelegate::Private::replaceNewlines(const QString &text) const
 }
 
 // Lays the text out in a rectangle no larger than constraints, eliding it as necessary
-QSize KFileItemDelegate::Private::layoutText(QTextLayout &layout, const QStyleOptionViewItemV4 &option,
+QSize KFileItemDelegate::Private::layoutText(QTextLayout &layout, const QStyleOptionViewItem &option,
         const QString &text, const QSize &constraints) const
 {
     const QSize size = layoutText(layout, text, constraints.width());
@@ -367,14 +367,14 @@ QSize KFileItemDelegate::Private::layoutText(QTextLayout &layout, const QString
 // or word breaking the line if it's wider than the max width, and finally adding an
 // ellipses at the end of the last line, if there are more lines than will fit within
 // the vertical size constraints.
-QString KFileItemDelegate::Private::elidedText(QTextLayout &layout, const QStyleOptionViewItemV4 &option,
+QString KFileItemDelegate::Private::elidedText(QTextLayout &layout, const QStyleOptionViewItem &option,
         const QSize &size) const
 {
     const QString text = layout.text();
     int maxWidth       = size.width();
     int maxHeight      = size.height();
     qreal height       = 0;
-    bool wrapText      = (option.features & QStyleOptionViewItemV2::WrapText);
+    bool wrapText      = (option.features & QStyleOptionViewItem::WrapText);
 
     // If the string contains a single line of text that shouldn't be word wrapped
     if (!wrapText && text.indexOf(QChar::LineSeparator) == -1) {
@@ -415,24 +415,24 @@ QString KFileItemDelegate::Private::elidedText(QTextLayout &layout, const QStyle
     return elided;
 }
 
-void KFileItemDelegate::Private::setLayoutOptions(QTextLayout &layout, const QStyleOptionViewItemV4 &option) const
+void KFileItemDelegate::Private::setLayoutOptions(QTextLayout &layout, const QStyleOptionViewItem &option) const
 {
     QTextOption textoption;
     textoption.setTextDirection(option.direction);
     textoption.setAlignment(QStyle::visualAlignment(option.direction, option.displayAlignment));
-    textoption.setWrapMode((option.features & QStyleOptionViewItemV2::WrapText) ? wrapMode : QTextOption::NoWrap);
+    textoption.setWrapMode((option.features & QStyleOptionViewItem::WrapText) ? wrapMode : QTextOption::NoWrap);
 
     layout.setFont(option.font);
     layout.setTextOption(textoption);
 }
 
-QSize KFileItemDelegate::Private::displaySizeHint(const QStyleOptionViewItemV4 &option,
+QSize KFileItemDelegate::Private::displaySizeHint(const QStyleOptionViewItem &option,
         const QModelIndex &index) const
 {
     QString label = option.text;
     int maxWidth = 0;
     if (maximumSize.isEmpty()) {
-        maxWidth = verticalLayout(option) && (option.features & QStyleOptionViewItemV2::WrapText)
+        maxWidth = verticalLayout(option) && (option.features & QStyleOptionViewItem::WrapText)
                    ? option.decorationSize.width() + 10 : 32757;
     } else {
         const Margin &itemMargin = activeMargins[ItemMargin];
@@ -448,7 +448,7 @@ QSize KFileItemDelegate::Private::displaySizeHint(const QStyleOptionViewItemV4 &
     // the information string to the label
     const QString info = information(option, index, item);
     if (!info.isEmpty()) {
-        label += QString(QChar::LineSeparator) + info;
+        label += QChar(QChar::LineSeparator) + info;
     }
 
     QTextLayout layout;
@@ -466,7 +466,7 @@ QSize KFileItemDelegate::Private::displaySizeHint(const QStyleOptionViewItemV4 &
     return addMargin(size, TextMargin);
 }
 
-QSize KFileItemDelegate::Private::decorationSizeHint(const QStyleOptionViewItemV4 &option,
+QSize KFileItemDelegate::Private::decorationSizeHint(const QStyleOptionViewItem &option,
         const QModelIndex &index) const
 {
     Q_UNUSED(index)
@@ -484,14 +484,14 @@ QSize KFileItemDelegate::Private::decorationSizeHint(const QStyleOptionViewItemV
     return addMargin(iconSize, IconMargin);
 }
 
-bool KFileItemDelegate::Private::verticalLayout(const QStyleOptionViewItemV4 &option) const
+bool KFileItemDelegate::Private::verticalLayout(const QStyleOptionViewItem &option) const
 {
     return (option.decorationPosition == QStyleOptionViewItem::Top ||
             option.decorationPosition == QStyleOptionViewItem::Bottom);
 }
 
 // Converts a QVariant of type Brush or Color to a QBrush
-QBrush KFileItemDelegate::Private::brush(const QVariant &value, const QStyleOptionViewItemV4 &option) const
+QBrush KFileItemDelegate::Private::brush(const QVariant &value, const QStyleOptionViewItem &option) const
 {
     if (value.userType() == qMetaTypeId<KStatefulBrush>()) {
         return qvariant_cast<KStatefulBrush>(value).brush(option.palette);
@@ -508,7 +508,7 @@ QBrush KFileItemDelegate::Private::brush(const QVariant &value, const QStyleOpti
     }
 }
 
-QBrush KFileItemDelegate::Private::foregroundBrush(const QStyleOptionViewItemV4 &option, const QModelIndex &index) const
+QBrush KFileItemDelegate::Private::foregroundBrush(const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
     QPalette::ColorGroup cg = QPalette::Active;
     if (!(option.state & QStyle::State_Enabled)) {
@@ -531,7 +531,7 @@ QBrush KFileItemDelegate::Private::foregroundBrush(const QStyleOptionViewItemV4
     return option.palette.brush(cg, QPalette::Text);
 }
 
-bool KFileItemDelegate::Private::isListView(const QStyleOptionViewItemV4 &option) const
+bool KFileItemDelegate::Private::isListView(const QStyleOptionViewItem &option) const
 {
     if (qobject_cast<const QListView *>(option.widget) || verticalLayout(option)) {
         return true;
@@ -564,19 +564,19 @@ void KFileItemDelegate::Private::restartAnimation(KIO::AnimationState *state)
     animationHandler->restartAnimation(state);
 }
 
-KIO::AnimationState *KFileItemDelegate::Private::animationState(const QStyleOptionViewItemV4 &option,
+KIO::AnimationState *KFileItemDelegate::Private::animationState(const QStyleOptionViewItem &option,
         const QModelIndex &index,
         const QAbstractItemView *view) const
 {
-    if (!option.widget->style()->styleHint(QStyle::SH_Widget_Animate, 0, option.widget)) {
-        return NULL;
+    if (!option.widget->style()->styleHint(QStyle::SH_Widget_Animate, nullptr, option.widget)) {
+        return nullptr;
     }
 
     if (index.column() == KDirModel::Name) {
         return animationHandler->animationState(option, index, view);
     }
 
-    return NULL;
+    return nullptr;
 }
 
 QPixmap KFileItemDelegate::Private::transition(const QPixmap &from, const QPixmap &to, qreal amount) const
@@ -692,7 +692,7 @@ QPixmap KFileItemDelegate::Private::transition(const QPixmap &from, const QPixma
     }
 }
 
-void KFileItemDelegate::Private::layoutTextItems(const QStyleOptionViewItemV4 &option, const QModelIndex &index,
+void KFileItemDelegate::Private::layoutTextItems(const QStyleOptionViewItem &option, const QModelIndex &index,
         QTextLayout *labelLayout, QTextLayout *infoLayout,
         QRect *textBoundingRect) const
 {
@@ -792,7 +792,7 @@ void KFileItemDelegate::Private::drawTextItems(QPainter *painter, const QTextLay
     }
 }
 
-void KFileItemDelegate::Private::initStyleOption(QStyleOptionViewItemV4 *option,
+void KFileItemDelegate::Private::initStyleOption(QStyleOptionViewItem *option,
         const QModelIndex &index) const
 {
     const KFileItem item = fileItem(index);
@@ -828,19 +828,20 @@ void KFileItemDelegate::Private::initStyleOption(QStyleOptionViewItemV4 *option,
 
     option->text = display(index);
     if (!option->text.isEmpty()) {
-        option->features |= QStyleOptionViewItemV2::HasDisplay;
+        option->features |= QStyleOptionViewItem::HasDisplay;
     }
 
     option->icon = decoration(*option, index);
+    // Note that even null icons are still drawn for alignment
     if (!option->icon.isNull()) {
-        option->features |= QStyleOptionViewItemV2::HasDecoration;
+        option->features |= QStyleOptionViewItem::HasDecoration;
     }
 
     // ### Make sure this value is always true for now
     option->showDecorationSelected = true;
 }
 
-void KFileItemDelegate::Private::paintJobTransfers(QPainter *painter, const qreal &jobAnimationAngle, const QPoint &iconPos, const QStyleOptionViewItemV4 &opt)
+void KFileItemDelegate::Private::paintJobTransfers(QPainter *painter, const qreal &jobAnimationAngle, const QPoint &iconPos, const QStyleOptionViewItem &opt)
 {
     painter->save();
     QSize iconSize = opt.icon.actualSize(opt.decorationSize);
@@ -916,7 +917,7 @@ QSize KFileItemDelegate::sizeHint(const QStyleOptionViewItem &option, const QMod
         return qvariant_cast<QSize>(value);
     }
 
-    QStyleOptionViewItemV4 opt(option);
+    QStyleOptionViewItem opt(option);
     d->initStyleOption(&opt, index);
     d->setActiveMargins(d->verticalLayout(opt) ? Qt::Vertical : Qt::Horizontal);
 
@@ -1048,7 +1049,7 @@ QTextOption::WrapMode KFileItemDelegate::wrapMode() const
 
 QRect KFileItemDelegate::iconRect(const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
-    QStyleOptionViewItemV4 opt(option);
+    QStyleOptionViewItem opt(option);
     d->initStyleOption(&opt, index);
     return QRect(d->iconPosition(opt), opt.icon.actualSize(opt.decorationSize));
 }
@@ -1064,7 +1065,7 @@ bool KFileItemDelegate::jobTransfersVisible() const
     return d->jobTransfersVisible;
 }
 
-QIcon KFileItemDelegate::Private::decoration(const QStyleOptionViewItemV4 &option, const QModelIndex &index) const
+QIcon KFileItemDelegate::Private::decoration(const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
     const QVariant value = index.data(Qt::DecorationRole);
     QIcon icon;
@@ -1092,12 +1093,8 @@ QIcon KFileItemDelegate::Private::decoration(const QStyleOptionViewItemV4 &optio
     return icon;
 }
 
-QRect KFileItemDelegate::Private::labelRectangle(const QStyleOptionViewItemV4 &option) const
+QRect KFileItemDelegate::Private::labelRectangle(const QStyleOptionViewItem &option) const
 {
-    if (option.icon.isNull()) {
-        return subtractMargin(option.rect, Private::ItemMargin);
-    }
-
     const QSize decoSize = addMargin(option.decorationSize, Private::IconMargin);
     const QRect itemRect = subtractMargin(option.rect, Private::ItemMargin);
     QRect textArea(QPoint(0, 0), itemRect.size());
@@ -1124,7 +1121,7 @@ QRect KFileItemDelegate::Private::labelRectangle(const QStyleOptionViewItemV4 &o
     return QStyle::visualRect(option.direction, option.rect, textArea);
 }
 
-QPoint KFileItemDelegate::Private::iconPosition(const QStyleOptionViewItemV4 &option) const
+QPoint KFileItemDelegate::Private::iconPosition(const QStyleOptionViewItem &option) const
 {
     const QRect itemRect = subtractMargin(option.rect, Private::ItemMargin);
     Qt::Alignment alignment;
@@ -1159,7 +1156,7 @@ QPoint KFileItemDelegate::Private::iconPosition(const QStyleOptionViewItemV4 &op
     return iconRect.topLeft();
 }
 
-void KFileItemDelegate::Private::drawFocusRect(QPainter *painter, const QStyleOptionViewItemV4 &option,
+void KFileItemDelegate::Private::drawFocusRect(QPainter *painter, const QStyleOptionViewItem &option,
         const QRect &rect) const
 {
     if (!(option.state & QStyle::State_HasFocus)) {
@@ -1191,7 +1188,7 @@ void KFileItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opt
         return;
     }
 
-    QStyleOptionViewItemV4 opt(option);
+    QStyleOptionViewItem opt(option);
     d->initStyleOption(&opt, index);
     d->setActiveMargins(d->verticalLayout(opt) ? Qt::Vertical : Qt::Horizontal);
 
@@ -1203,7 +1200,7 @@ void KFileItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opt
     if (index.column() > 0) {
         opt.state &= ~QStyle::State_MouseOver;
     } else {
-        opt.viewItemPosition = QStyleOptionViewItemV4::OnlyOne;
+        opt.viewItemPosition = QStyleOptionViewItem::OnlyOne;
     }
 
     const QAbstractItemView *view = qobject_cast<const QAbstractItemView *>(opt.widget);
@@ -1211,11 +1208,20 @@ void KFileItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opt
     // Check if the item is being animated
     // ========================================================================
     KIO::AnimationState *state = d->animationState(opt, index, view);
-    KIO::CachedRendering *cache = 0;
+    KIO::CachedRendering *cache = nullptr;
     qreal progress = ((opt.state & QStyle::State_MouseOver) &&
                       index.column() == KDirModel::Name) ? 1.0 : 0.0;
     const QPoint iconPos   = d->iconPosition(opt);
-    QIcon::Mode iconMode   = option.state & QStyle::State_Enabled ? QIcon::Normal : QIcon::Disabled;
+    QIcon::Mode iconMode;
+
+    if (!(option.state & QStyle::State_Enabled)) {
+        iconMode = QIcon::Disabled;
+    } else if ((option.state & QStyle::State_Selected) && (option.state & QStyle::State_Active)) {
+        iconMode = QIcon::Selected;
+    } else {
+        iconMode = QIcon::Normal;
+    }
+
     QIcon::State iconState = option.state & QStyle::State_Open ? QIcon::On : QIcon::Off;
     QPixmap icon           = opt.icon.pixmap(opt.decorationSize, iconMode, iconState);
 
@@ -1247,7 +1253,7 @@ void KFileItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opt
             }
 
             if (!cache->checkValidity(opt.state)) {
-                if (opt.widget->style()->styleHint(QStyle::SH_Widget_Animate, 0, opt.widget)) {
+                if (opt.widget->style()->styleHint(QStyle::SH_Widget_Animate, nullptr, opt.widget)) {
                     // Fade over from the old icon to the new one
                     // Only start a new fade if the previous one is ready
                     // Else we may start racing when checkValidity() always returns false
@@ -1258,7 +1264,7 @@ void KFileItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opt
                 d->gotNewIcon(index);
             }
             // If it wasn't valid, delete it
-            state->setCachedRendering(0);
+            state->setCachedRendering(nullptr);
         } else {
             // The cache may have been discarded, but the animation handler still needs to know about new icons
             d->gotNewIcon(index);
@@ -1289,7 +1295,9 @@ void KFileItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opt
     // know yet if a hover out animation will be run.
     // ========================================================================
     if (state && (state->hoverProgress() < 1 || state->fadeProgress() < 1)) {
-        cache = new KIO::CachedRendering(opt.state, option.rect.size(), index, painter->device()->devicePixelRatio());
+        const qreal dpr = painter->device()->devicePixelRatioF();
+
+        cache = new KIO::CachedRendering(opt.state, option.rect.size(), index, dpr);
 
         QPainter p;
         p.begin(&cache->regular);
@@ -1367,7 +1375,7 @@ void KFileItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opt
 QWidget *KFileItemDelegate::createEditor(QWidget *parent, const QStyleOptionViewItem &option,
         const QModelIndex &index) const
 {
-    QStyleOptionViewItemV4 opt(option);
+    QStyleOptionViewItem opt(option);
     d->initStyleOption(&opt, index);
 
     QTextEdit *edit = new QTextEdit(parent);
@@ -1393,7 +1401,7 @@ bool KFileItemDelegate::editorEvent(QEvent *event, QAbstractItemModel *model, co
 void KFileItemDelegate::setEditorData(QWidget *editor, const QModelIndex &index) const
 {
     QTextEdit *textedit = qobject_cast<QTextEdit *>(editor);
-    Q_ASSERT(textedit != 0);
+    Q_ASSERT(textedit != nullptr);
 
     //Do not update existing text that the user may already have edited.
     //The models will call setEditorData(..) whenever the icon has changed,
@@ -1424,7 +1432,7 @@ void KFileItemDelegate::setEditorData(QWidget *editor, const QModelIndex &index)
 void KFileItemDelegate::setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const
 {
     QTextEdit *textedit = qobject_cast<QTextEdit *>(editor);
-    Q_ASSERT(textedit != 0);
+    Q_ASSERT(textedit != nullptr);
 
     model->setData(index, textedit->toPlainText(), Qt::EditRole);
 }
@@ -1432,7 +1440,7 @@ void KFileItemDelegate::setModelData(QWidget *editor, QAbstractItemModel *model,
 void KFileItemDelegate::updateEditorGeometry(QWidget *editor, const QStyleOptionViewItem &option,
         const QModelIndex &index) const
 {
-    QStyleOptionViewItemV4 opt(option);
+    QStyleOptionViewItem opt(option);
     d->initStyleOption(&opt, index);
     d->setActiveMargins(d->verticalLayout(opt) ? Qt::Vertical : Qt::Horizontal);
 
@@ -1458,7 +1466,7 @@ void KFileItemDelegate::updateEditorGeometry(QWidget *editor, const QStyleOption
     }
 
     QTextEdit *textedit = qobject_cast<QTextEdit *>(editor);
-    Q_ASSERT(textedit != 0);
+    Q_ASSERT(textedit != nullptr);
     const int frame = textedit->frameWidth();
     r.adjust(-frame, -frame, frame, frame);
 
@@ -1489,7 +1497,7 @@ bool KFileItemDelegate::helpEvent(QHelpEvent *event, QAbstractItemView *view, co
 
     // in the case the tooltip information is the same as the display information,
     // show it only in the case the display information is elided
-    QStyleOptionViewItemV4 opt(option);
+    QStyleOptionViewItem opt(option);
     d->initStyleOption(&opt, index);
     d->setActiveMargins(d->verticalLayout(opt) ? Qt::Vertical : Qt::Horizontal);
 
@@ -1508,7 +1516,7 @@ bool KFileItemDelegate::helpEvent(QHelpEvent *event, QAbstractItemView *view, co
 
 QRegion KFileItemDelegate::shape(const QStyleOptionViewItem &option, const QModelIndex &index)
 {
-    QStyleOptionViewItemV4 opt(option);
+    QStyleOptionViewItem opt(option);
     d->initStyleOption(&opt, index);
     d->setActiveMargins(d->verticalLayout(opt) ? Qt::Vertical : Qt::Horizontal);
 
