@@ -55,6 +55,9 @@
 #include <kprotocolinfo.h>
 #include <qmimedatabase.h>
 #include <qstandardpaths.h>
+#include <KMountPoint>
+
+#include <algorithm>
 
 #include "job_p.h"
 
@@ -270,6 +273,7 @@ void PreviewJobPrivate::startPreview()
     const KService::List plugins = KServiceTypeTrader::self()->query(QStringLiteral("ThumbCreator"));
     QMap<QString, KService::Ptr> mimeMap;
     QHash<QString, QHash<QString, KService::Ptr> > protocolMap;
+
     for (KService::List::ConstIterator it = plugins.constBegin(); it != plugins.constEnd(); ++it) {
         QStringList protocols = (*it)->property(QStringLiteral("X-KDE-Protocols")).toStringList();
         const QString p = (*it)->property(QStringLiteral("X-KDE-Protocol")).toString();
@@ -300,6 +304,18 @@ void PreviewJobPrivate::startPreview()
         }
     }
 
+    const auto mountsList = KMountPoint::currentMountPoints();
+    KMountPoint::List encryptedMountsList;
+    const auto thumbRootMount = mountsList.findByPath(thumbRoot);
+
+    std::copy_if(mountsList.begin(), mountsList.end(),
+                 std::back_inserter(encryptedMountsList),
+                 [&thumbRootMount] (KMountPoint::Ptr mount) {
+                     return (thumbRootMount != mount) &&
+                            (mount->mountType() == QLatin1String("fuse.cryfs") ||
+                             mount->mountType() == QLatin1String("fuse.encfs"));
+                 });
+
     // Look for images and store the items in our todo list :)
     bool bNeedCache = false;
     KFileItemList::const_iterator kit = initialItems.constBegin();
@@ -307,6 +323,11 @@ void PreviewJobPrivate::startPreview()
     for (; kit != kend; ++kit) {
         PreviewItem item;
         item.item = *kit;
+
+        if (encryptedMountsList.findByPath(item.item.localPath())) {
+            continue;
+        }
+
         const QString mimeType = item.item.mimetype();
         KService::Ptr plugin(nullptr);
 
@@ -464,7 +485,7 @@ void PreviewJob::slotResult(KJob *job)
             return;
         }
         const KIO::UDSEntry entry = static_cast<KIO::StatJob *>(job)->statResult();
-        d->tOrig = QDateTime::fromTime_t(entry.numberValue(KIO::UDSEntry::UDS_MODIFICATION_TIME, 0));
+        d->tOrig = QDateTime::fromSecsSinceEpoch(entry.numberValue(KIO::UDSEntry::UDS_MODIFICATION_TIME, 0));
 
         bool skipCurrentItem = false;
         const KIO::filesize_t size = (KIO::filesize_t)entry.numberValue(KIO::UDSEntry::UDS_SIZE, 0);
@@ -545,7 +566,7 @@ bool PreviewJobPrivate::statResultThumbnail()
     }
 
     if (thumb.text(QStringLiteral("Thumb::URI")) != QString::fromUtf8(origName) ||
-            thumb.text(QStringLiteral("Thumb::MTime")).toLongLong() != tOrig.toTime_t()) {
+            thumb.text(QStringLiteral("Thumb::MTime")).toLongLong() != tOrig.toSecsSinceEpoch()) {
         return false;
     }
 
@@ -699,7 +720,7 @@ void PreviewJobPrivate::slotThumbData(KIO::Job *, const QByteArray &data)
 
     if (save) {
         thumb.setText(QStringLiteral("Thumb::URI"), QString::fromUtf8(origName));
-        thumb.setText(QStringLiteral("Thumb::MTime"), QString::number(tOrig.toTime_t()));
+        thumb.setText(QStringLiteral("Thumb::MTime"), QString::number(tOrig.toSecsSinceEpoch()));
         thumb.setText(QStringLiteral("Thumb::Size"), number(currentItem.item.size()));
         thumb.setText(QStringLiteral("Thumb::Mimetype"), currentItem.item.mimetype());
         QString thumbnailerVersion = currentItem.plugin->property(QStringLiteral("ThumbnailerVersion"), QVariant::String).toString();
